#!/bin/sh
# This script will run some tests for guix's python2 and python3,
# their sys.path, handing of site-packages, etc.

# Abort when any command fails.
set -e

# [Helper funtions]
function _do() {
    echo "$@"
    echo "============================================================"
}

function _ok() {
    echo "============================================================"
    echo
    echo
}

function _die() {
    echo "============================================================"
    echo "ERROR: $@" > /dev/stderr
    exit 1
}


# [Checks]
TESTDIR=$(pwd)/_test_

_do "Make sure we're in the checkout of guix."
./pre-inst-env guix --version || \
    _die "Please cd into the checkout of guix."
_ok

_do "Create a empty directory ${TESTDIR} for test."
mkdir ${TESTDIR} || \
    _die "If it exists alrealy, you can delete it manually."
_ok

_do "Install python2, python3 and some packages to a profile."
./pre-inst-env guix package -i python python2 python-virtualenv python-click python2-click -p ${TESTDIR}/profile || \
    _die "Are you on the right commit, eg: HEAD of core-updates branch?"
_ok

_do "Setup the environment variables."
for i in `env | cut -d '=' -f 1 | grep PYTHON`; do
    unset $i
done
source ${TESTDIR}/profile/etc/profile
_ok

_do "Check python2 can import its site-packages in the profile."
python2 -c 'import click; print(click)' || \
    _die "Failed."
_ok

_do "Check python3 can import its site-packages in the profile."
python3 -c 'import click; print(click)' || \
    _die "Failed."
_ok

_do "Check python2 can't import its site-packages with '-S' option."
python2 -Sc 'import click; print(click)' && \
    _die "Failed."
_ok

_do "Check python3 can't import its site-packages with '-S' option."
python3 -Sc 'import click; print(click)' && \
    _die "Failed."
_ok

_do "Create virtual environments."
virtualenv -p python2 ${TESTDIR}/py2-virtualenv
virtualenv -p python2 --system-site-packages ${TESTDIR}/py2-virtualenv+system-site-packages
virtualenv -p python3 ${TESTDIR}/py3-virtualenv
virtualenv -p python3 --system-site-packages ${TESTDIR}/py3-virtualenv+system-site-packages
python3 -m venv ${TESTDIR}/py3-venv
python3 -m venv --system-site-packages ${TESTDIR}/py3-venv+system-site-packages
_ok

_do "Check virtual environments without system-site-packages."
${TESTDIR}/py2-virtualenv/bin/python -c 'import click; print(click)' && \
    _die "Failed."
${TESTDIR}/py3-virtualenv/bin/python -c 'import click; print(click)' && \
    _die "Failed."
${TESTDIR}/py3-venv/bin/python -c 'import click; print(click)' && \
    _die "Failed."
_ok

_do "Check vitual environments with system-site-packages."
${TESTDIR}/py2-virtualenv+system-site-packages/bin/python -c 'import click; print(click)' || \
    _die "Failed."
${TESTDIR}/py3-virtualenv+system-site-packages/bin/python -c 'import click; print(click)' || \
    _die "Failed."
${TESTDIR}/py3-venv+system-site-packages/bin/python -c 'import click; print(click)' || \
    _die "Failed."
_ok

_do "Check virtual environments with system-site-packages and '-S' option."
${TESTDIR}/py2-virtualenv+system-site-packages/bin/python -Sc 'import click; print(click)' && \
    _die "Failed."
${TESTDIR}/py3-virtualenv+system-site-packages/bin/python -Sc 'import click; print(click)' && \
    _die "Failed."
${TESTDIR}/py3-venv+system-site-packages/bin/python -Sc 'import click; print(click)' && \
    _die "Failed."
_ok



echo "Looks good so far!"
echo "${TESTDIR} is available for future tests..."
